==> estateplat-common-1.2.3-20180316.074822-45-sources.jar: cn/gtmap/estateplat/model/register/WwDjModel.java <==
package cn.gtmap.estateplat.model.register;

import cn.gtmap.estateplat.model.exchange.share.*;

import java.io.Serializable;
import java.util.List;

/**
 * 共享外网申请信息表.
 */
public class WwDjModel implements Serializable {
    private List<GxWwSqxxFjxx> gxWwSqxxFjxxList;
    private List<GxWwSqxxClxx> gxWwSqxxClxxList;
    private List<GxWwSqxx> gxWwSqxxList;
    private List<GxWwSqxxQlr> gxWwSqxxQlrList;
    private List<GxWwSqxm> gxWwSqxmList;
    private List<GxWwYyxx> gxWwYyxxList;

    public List<GxWwSqxxFjxx> getGxWwSqxxFjxxList() {
        return gxWwSqxxFjxxList;
    }

    public void setGxWwSqxxFjxxList(List<GxWwSqxxFjxx> gxWwSqxxFjxxList) {
        this.gxWwSqxxFjxxList = gxWwSqxxFjxxList;
    }

    public List<GxWwSqxxClxx> getGxWwSqxxClxxList() {
        return gxWwSqxxClxxList;
    }

    public void setGxWwSqxxClxxList(List<GxWwSqxxClxx> gxWwSqxxClxxList) {
        this.gxWwSqxxClxxList = gxWwSqxxClxxList;
    }

    public List<GxWwSqxx> getGxWwSqxxList() {
        return gxWwSqxxList;
    }

    public void setGxWwSqxxList(List<GxWwSqxx> gxWwSqxxList) {
        this.gxWwSqxxList = gxWwSqxxList;
    }

    public List<GxWwSqxxQlr> getGxWwSqxxQlrList() {
        return gxWwSqxxQlrList;
    }

    public void setGxWwSqxxQlrList(List<GxWwSqxxQlr> gxWwSqxxQlrList) {
        this.gxWwSqxxQlrList = gxWwSqxxQlrList;
    }

    public List<GxWwSqxm> getGxWwSqxmList() {
        return gxWwSqxmList;
    }

    public void setGxWwSqxmList(List<GxWwSqxm> gxWwSqxmList) {
        this.gxWwSqxmList = gxWwSqxmList;
    }

    public List<GxWwYyxx> getGxWwYyxxList() {
        return gxWwYyxxList;
    }

    public void setGxWwYyxxList(List<GxWwYyxx> gxWwYyxxList) {
        this.gxWwYyxxList = gxWwYyxxList;
    }
}

==> estateplat-common-1.2.3-20180706.091355-141-sources.jar: cn/gtmap/estateplat/model/register/WwDjModel.java <==
package cn.gtmap.estateplat.model.register;

import cn.gtmap.estateplat.model.exchange.court.GxPeKzqq;
import cn.gtmap.estateplat.model.exchange.share.*;

import java.io.Serializable;
import java.util.List;

/**
 * 共享外网申请信息表.
 */
public class WwDjModel implements Serializable {
    private List<GxWwSqxxFjxx> gxWwSqxxFjxxList;
    private List<GxWwSqxxClxx> gxWwSqxxClxxList;
    private List<GxWwSqxx> gxWwSqxxList;
    private List<GxWwSqxxQlr> gxWwSqxxQlrList;
    private List<GxWwSqxm> gxWwSqxmList;
    private List<GxWwYyxx> gxWwYyxxList;
    private List<GxPeKzqq> gxPeKzqqList; //法院查控

    public List<GxWwSqxxFjxx> getGxWwSqxxFjxxList() {
        return gxWwSqxxFjxxList;
    }

    public void setGxWwSqxxFjxxList(List<GxWwSqxxFjxx> gxWwSqxxFjxxList) {
        this.gxWwSqxxFjxxList = gxWwSqxxFjxxList;
    }

    public List<GxWwSqxxClxx> getGxWwSqxxClxxList() {
        return gxWwSqxxClxxList;
    }

    public void setGxWwSqxxClxxList(List<GxWwSqxxClxx> gxWwSqxxClxxList) {
        this.gxWwSqxxClxxList = gxWwSqxxClxxList;
    }

    public List<GxWwSqxx> getGxWwSqxxList() {
        return gxWwSqxxList;
    }

    public void setGxWwSqxxList(List<GxWwSqxx> gxWwSqxxList) {
        this.gxWwSqxxList = gxWwSqxxList;
    }

    public List<GxWwSqxxQlr> getGxWwSqxxQlrList() {
        return gxWwSqxxQlrList;
    }

    public void setGxWwSqxxQlrList(List<GxWwSqxxQlr> gxWwSqxxQlrList) {
        this.gxWwSqxxQlrList = gxWwSqxxQlrList;
    }

    public List<GxWwSqxm> getGxWwSqxmList() {
        return gxWwSqxmList;
    }

    public void setGxWwSqxmList(List<GxWwSqxm> gxWwSqxmList) {
        this.gxWwSqxmList = gxWwSqxmList;
    }

    public List<GxWwYyxx> getGxWwYyxxList() {
        return gxWwYyxxList;
    }

    public void setGxWwYyxxList(List<GxWwYyxx> gxWwYyxxList) {
        this.gxWwYyxxList = gxWwYyxxList;
    }

    public List<GxPeKzqq> getGxPeKzqqList() {
        return gxPeKzqqList;
    }

    public void setGxPeKzqqList(List<GxPeKzqq> gxPeKzqqList) {
        this.gxPeKzqqList = gxPeKzqqList;
    }
}
